@@ -33,9 +33,9 @@ if (empty($SOURCES['dependencies'])) {
     rcube::raise_error("Failed to read dependencies list from $cfgfile", false, true);
 }
 
-$CURL     = trim(`which curl`);
-$WGET     = trim(`which wget`);
-$UNZIP    = trim(`which unzip`);
+$CURL  = trim(`which curl`);
+$WGET  = trim(`which wget`);
+$UNZIP = trim(`which unzip`);
 
 if (($CACHEDIR = getenv("CACHEDIR")) && is_writeable($CACHEDIR)) {
     // use $CACHEDIR
@@ -50,7 +50,7 @@ else {
 
 //////////////// License definitions
 
-$LICENSES = array();
+$LICENSES = [];
 $LICENSES['MIT'] = <<<EOM
  * Licensed under the MIT licenses
  *
@@ -122,22 +122,26 @@ function fetch_from_source($package, $useCache = true, &$filetype = null)
 
         echo "Fetching $url\n";
 
-        if ($CURL)
+        if ($CURL) {
             exec(sprintf('%s -L -s %s -o %s', $CURL, escapeshellarg($url), $cache_file), $out, $retval);
-        else
+        }
+        else {
             exec(sprintf('%s -q %s -O %s', $WGET, escapeshellarg($url), $cache_file), $out, $retval);
+        }
 
         // Try Github API as a fallback (#6248)
-        if ($retval !== 0 && $package['api_url']) {
+        if ($retval !== 0 && !empty($package['api_url'])) {
             $url    = str_replace('$v', $package['version'], $package['api_url']);
             $header = 'Accept:application/vnd.github.v3.raw';
 
             rcube::raise_error("Fetching failed. Using Github API on $url");
 
-            if ($CURL)
+            if ($CURL) {
                 exec(sprintf('%s -L -H %s -s %s -o %s', $CURL, escapeshellarg($header), escapeshellarg($url), $cache_file), $out, $retval);
-            else
+            }
+            else {
                 exec(sprintf('%s --header %s -q %s -O %s', $WGET, escapeshellarg($header), escapeshellarg($url), $cache_file), $out, $retval);
+            }
         }
 
         if ($retval !== 0) {
@@ -245,7 +249,7 @@ function extract_zipfile($package, $srcfile)
             mkdir($extract, 0774, true);
         }
 
-        $zip_command = '%s -' . ($package['flat'] ? 'j' : 'o') . ' %s -d %s';
+        $zip_command = '%s -' . (!empty($package['flat']) ? 'j' : 'o') . ' %s -d %s';
         exec(sprintf($zip_command, $UNZIP, escapeshellarg($srcfile), $extract), $out, $retval);
 
         // get the root folder of the extracted package
@@ -256,7 +260,7 @@ function extract_zipfile($package, $srcfile)
             echo "Installing $sourcedir/$src into $destdir/$dest\n";
 
             $dest_file = $destdir . '/' . $dest;
-            $src_file = $sourcedir . '/' . $src;
+            $src_file  = $sourcedir . '/' . $src;
 
             // make sure the destination's parent directory exists
             if (strpos($dest, '/') !== false) {
@@ -321,7 +325,7 @@ function extract_zipfile($package, $srcfile)
  */
 function delete_destfile($package)
 {
-    $destdir = INSTALL_PATH . ($package['rm'] ?: $package['dest']);
+    $destdir = INSTALL_PATH . (!empty($package['rm']) ? $package['rm'] : $package['dest']);
 
     if (file_exists($destdir)) {
         if (PHP_OS === 'Windows') {
@@ -336,9 +340,20 @@ function delete_destfile($package)
 
 //////////////// Execution
 
-$args = rcube_utils::get_opt(array('f' => 'force:bool', 'd' => 'delete:bool', 'g' => 'get:bool', 'e' => 'extract:bool'))
-        + array('force' => false, 'delete' => false, 'get' => false, 'extract' => false);
-$WHAT = $args[0];
+$args = rcube_utils::get_opt([
+        'f' => 'force:bool',
+        'd' => 'delete:bool',
+        'g' => 'get:bool',
+        'e' => 'extract:bool'
+    ])
+    + [
+        'force'   => false,
+        'delete'  => false,
+        'get'     => false,
+        'extract' => false
+    ];
+
+$WHAT     = isset($args[0]) ? $args[0] : null;
 $useCache = !$args['force'] && !$args['get'];
 
 if (!$args['get'] && !$args['extract'] && !$args['delete']) {
