@@ -2,8 +2,7 @@
 
 class ExampleAddressbook_Plugin extends PHPUnit\Framework\TestCase
 {
-
-    function setUp()
+    public static function setUpBeforeClass(): void
     {
         include_once __DIR__ . '/../example_addressbook.php';
         include_once __DIR__ . '/../example_addressbook_backend.php';
