@@ -2,8 +2,7 @@
 
 class Password_Plugin extends PHPUnit\Framework\TestCase
 {
-
-    function setUp()
+    public static function setUpBeforeClass(): void
     {
         include_once __DIR__ . '/../password.php';
     }
@@ -84,7 +83,7 @@ class Password_Plugin extends PHPUnit\Framework\TestCase
     function load_driver($driver)
     {
         include_once __DIR__ . "/../drivers/$driver.php";
-        $driver_class = "rcube_${driver}_password";
+        $driver_class = "rcube_{$driver}_password";
         $this->assertTrue(class_exists($driver_class));
         return $driver_class;
     }
@@ -101,10 +100,16 @@ class Password_Plugin extends PHPUnit\Framework\TestCase
         $this->assertSame("\"\0t\0e\0s\0t\0\"\0", $pass);
 
         $pass = password::hash_password('test', 'ssha');
-        $this->assertRegExp('/^\{SSHA\}[a-zA-Z0-9+\/]{32}$/', $pass);
+        $this->assertMatchesRegularExpression('/^\{SSHA\}[a-zA-Z0-9+\/]{32}$/', $pass);
+
+        $pass = password::hash_password('test', 'ssha256');
+        $this->assertMatchesRegularExpression('/^\{SSHA256\}[a-zA-Z0-9+\/=]{48}$/', $pass);
 
         $pass = password::hash_password('test', 'sha256-crypt');
-        $this->assertRegExp('/^\{CRYPT\}\$5\$[a-zA-Z0-9]{16}\$[a-zA-Z0-9.\/]{43}$/', $pass);
+        $this->assertMatchesRegularExpression('/^\{SHA256-CRYPT\}\$5\$[a-zA-Z0-9]{16}\$[a-zA-Z0-9.\/]{43}$/', $pass);
+
+        $pass = password::hash_password('test', 'hash-bcrypt');
+        $this->assertMatchesRegularExpression('/^\{BLF-CRYPT\}\$2y\$10\$[a-zA-Z0-9.\/]{53}$/', $pass);
 
         // TODO: Test all algos
     }
