@@ -334,30 +334,37 @@ class rcube_plugin_api
         }
 
         // fall back to composer.json file
-        if (!$info) {
+        if (empty($info)) {
+            $info = [];
             $composer = INSTALL_PATH . "/plugins/$plugin_name/composer.json";
-            if (is_readable($composer) && ($json = @json_decode(file_get_contents($composer), true))) {
+
+            if (is_readable($composer) && ($json = json_decode(file_get_contents($composer), true))) {
                 // Build list of plugins required
                 $require = [];
-                foreach (array_keys((array) $json['require']) as $dname) {
-                    if (!preg_match('|^([^/]+)/([a-zA-Z0-9_-]+)$|', $dname, $m)) {
-                        continue;
-                    }
+                if (!empty($json['require'])) {
+                    foreach (array_keys((array) $json['require']) as $dname) {
+                        if (!preg_match('|^([^/]+)/([a-zA-Z0-9_-]+)$|', $dname, $m)) {
+                            continue;
+                        }
 
-                    $vendor = $m[1];
-                    $name   = $m[2];
+                        $vendor = $m[1];
+                        $name   = $m[2];
 
-                    if ($name != 'plugin-installer' && $vendor != 'pear' && $vendor != 'pear-pear') {
-                        $dpath = unslashify($dir->path) . "/$name/$name.php";
-                        if (is_readable($dpath)) {
-                            $require[] = $name;
+                        if ($name != 'plugin-installer' && $vendor != 'pear' && $vendor != 'pear-pear') {
+                            $dpath = unslashify($dir->path) . "/$name/$name.php";
+                            if (is_readable($dpath)) {
+                                $require[] = $name;
+                            }
                         }
                     }
                 }
 
-                list($info['vendor'], $info['name']) = explode('/', $json['name']);
-                $info['version'] = $json['version'];
-                $info['license'] = $json['license'];
+                if (!empty($json['name']) && is_string($json['name']) && strpos($json['name'], '/') !== false) {
+                    list($info['vendor'], $info['name']) = explode('/', $json['name'], 2);
+                }
+
+                $info['version'] = isset($json['version']) ? $json['version'] : null;
+                $info['license'] = isset($json['license']) ? $json['license'] : null;
                 $info['require'] = $require;
 
                 if (!empty($json['homepage'])) {
@@ -368,7 +375,7 @@ class rcube_plugin_api
             // read local composer.lock file (once)
             if (!isset($composer_lock)) {
                 $composer_lock = @json_decode(@file_get_contents(INSTALL_PATH . "/composer.lock"), true);
-                if ($composer_lock['packages']) {
+                if ($composer_lock && !empty($composer_lock['packages'])) {
                     foreach ($composer_lock['packages'] as $i => $package) {
                         $composer_lock['installed'][$package['name']] = $package;
                     }
@@ -376,18 +383,18 @@ class rcube_plugin_api
             }
 
             // load additional information from local composer.lock file
-            if (!empty($json['name']) && !empty($composer_lock['installed'])
+            if (!empty($json['name']) && $composer_lock && !empty($composer_lock['installed'])
                 && !empty($composer_lock['installed'][$json['name']])
             ) {
                 $lock            = $composer_lock['installed'][$json['name']];
                 $info['version'] = $lock['version'];
-                $info['uri']     = $lock['homepage'] ?: $lock['source']['uri'];
-                $info['src_uri'] = $lock['dist']['uri'] ?: $lock['source']['uri'];
+                $info['uri']     = !empty($lock['homepage']) ? $lock['homepage'] : $lock['source']['url'];
+                $info['src_uri'] = !empty($lock['dist']['url']) ? $lock['dist']['url'] : $lock['source']['url'];
             }
         }
 
         // fall back to package.xml file
-        if (!$info) {
+        if (empty($info)) {
             $package = INSTALL_PATH . "/plugins/$plugin_name/package.xml";
             if (is_readable($package) && ($file = file_get_contents($package))) {
                 $doc = new DOMDocument();
@@ -773,7 +780,7 @@ class rcube_plugin_api
     protected function template_container_hook($attrib)
     {
         $container     = $attrib['name'];
-        $content       = isset($attrib['content']) ? $attrib['content'] : '';
+        $content       = $attrib['content'] ?? '';
 
         if (isset($this->template_contents[$container])) {
             $content .= $this->template_contents[$container];
